@@ -162,6 +162,9 @@ static int tdp_max_x6fr5xx[] = { 0xa2, 0xa2, 0xc3 };
 static int tdp_min_xxxx45xs[] = { 0x0a, 0x0a, 0x0a };
 static int tdp_max_xxxx45xs[] = { 0x64, 0x64, 0x69 };
 
+static int tdp_min_x6ar55xu[] = { 0x0a, 0x0a, 0x0a };
+static int tdp_max_x6ar55xu[] = { 0x91, 0x9b, 0x122 };
+
 static int *tdp_min_defs = NULL;
 static int *tdp_max_defs = NULL;
 
@@ -248,6 +251,9 @@ static void uw_id_tdp(void)
 	} else if (dmi_match(DMI_BOARD_NAME, "X5KK45xS_X5SP45xS")) {
 		tdp_min_defs = tdp_min_xxxx45xs;
 		tdp_max_defs = tdp_max_xxxx45xs;
+	} else if (dmi_match(DMI_BOARD_NAME, "X6AR55xU")) {
+		tdp_min_defs = tdp_min_x6ar55xu;
+		tdp_max_defs = tdp_max_x6ar55xu;
 #endif
 	} else {
 		tdp_min_defs = NULL;
